@@ -1,18 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/* $Id: weather.c 10520 2007-11-14 21:49:57Z ryanl $ */
-
-/*
- *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
+/* weather.c - Overall weather server functions
  *
- *  This code released under the GNU GPL.
- *  Read the file COPYING for more information.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  Overall weather server functions.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -26,22 +31,34 @@
 #include <values.h>
 #endif
 
-#ifdef __FreeBSD__
-#include <sys/types.h>
-#endif
-#include <regex.h>
 #include <time.h>
 #include <unistd.h>
 
-#include <glib/gi18n-lib.h>
 #include <gtk/gtkicontheme.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
+#include <gconf/gconf-client.h>
 
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#include <libgweather/weather.h>
+#include "weather.h"
 #include "weather-priv.h"
 
+const char *
+gweather_gettext (const char *str)
+{
+    static gsize gweather_gettext_initialized = FALSE;
+
+    if (G_UNLIKELY (g_once_init_enter (&gweather_gettext_initialized))) {
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+	g_once_init_leave (&gweather_gettext_initialized, TRUE);
+    }
+
+    return dgettext (GETTEXT_PACKAGE, str);
+}
+
 /*
  * Convert string of the form "DD-MM-SSH" to radians
  * DD:degrees (to 3 digits), MM:minutes, SS:seconds H:hemisphere (NESW)
@@ -415,6 +432,43 @@ calc_apparent (WeatherInfo *info)
     return apparent;
 }
 
+static SoupSession *
+weather_session_new (void)
+{
+    SoupURI *proxy = NULL;
+    GConfClient *gconf;
+
+    gconf = gconf_client_get_default ();
+    if (gconf_client_get_bool (gconf, "/system/http_proxy/use_http_proxy", NULL)) {
+	char *host, *user, *password;
+	int port;
+
+	host = gconf_client_get_string (gconf, "/system/http_proxy/host", NULL);
+	port = gconf_client_get_int (gconf, "/system/http_proxy/port", NULL);
+	if (gconf_client_get_bool (gconf, "/system/http_proxy/use_authentication", NULL)) {
+	    user = gconf_client_get_string (gconf, "/system/http_proxy/authentication_user", NULL);
+	    password = gconf_client_get_string (gconf, "/system/http_proxy/authentication_password", NULL);
+	} else
+	    user = password = NULL;
+
+	if (host && *host) {
+	    proxy = soup_uri_new (NULL);
+	    soup_uri_set_scheme (proxy, SOUP_URI_SCHEME_HTTP);
+	    soup_uri_set_host (proxy, host);
+	    soup_uri_set_port (proxy, port);
+	    soup_uri_set_user (proxy, user);
+	    soup_uri_set_password (proxy, password);
+	}
+	g_free (host);
+	g_free (user);
+	g_free (password);
+
+	g_object_unref (gconf);
+    }
+
+    return soup_session_async_new_with_options (SOUP_SESSION_PROXY_URI, proxy,
+						NULL);
+}
 
 WeatherInfo *
 _weather_info_fill (WeatherInfo *info,
@@ -481,7 +535,7 @@ _weather_info_fill (WeatherInfo *info,
     info->cb_data = data;
 
     if (!info->session)
-	info->session = soup_session_async_new ();
+	info->session = weather_session_new ();
 
     metar_start_open (info);
     iwin_start_open (info);
@@ -560,6 +614,13 @@ weather_info_is_valid (WeatherInfo *info)
     return info->valid;
 }
 
+gboolean
+weather_info_network_error (WeatherInfo *info)
+{
+    g_return_val_if_fail (info != NULL, FALSE);
+    return info->network_error;
+}
+
 const WeatherLocation *
 weather_info_get_location (WeatherInfo *info)
 {
